@@ -25,7 +25,8 @@
 #ifndef TOTEM_PL_PARSER_MINI
 #include <string.h>
 #include <glib.h>
-#include <gtk/gtk.h>
+#include <stdio.h>
+
 #include "totem-pl-parser.h"
 #include "totemplparser-marshal.h"
 #include "totem-disc.h"
