@@ -26,14 +26,17 @@
 #ifdef XINE_COMPILE
 # include "config.h"
 #endif
-
-#include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
 #include <ctype.h>
 
+#ifdef _MSC_VER
+#define snprintf sprintf_s
+#define strcasecmp stricmp
+#endif
+
 #define LOG_MODULE "xmlparser"
 #define LOG_VERBOSE
 /*
@@ -364,6 +367,7 @@ static int xml_parser_get_node_internal (xml_parser_t *xml_parser,
 						    pname_buffer, pname_buffer_size,
 						    nname_buffer, nname_buffer_size,
 						    subtree, root_names, rec + 1, flags);
+	  tok = *token_buffer;
 	  free (root_names[rec + 1]);
 	  if (parse_res == -1 || parse_res > 0) {
 	    return parse_res;
@@ -412,8 +416,14 @@ static int xml_parser_get_node_internal (xml_parser_t *xml_parser,
 	  }
 	  /* make sure the buffer for the property name is big enough */
 	  if (*token_buffer_size > *pname_buffer_size) {
+	    char *tmp_prop;
 	    *pname_buffer_size = *token_buffer_size;
-	    *pname_buffer = realloc (*pname_buffer, *pname_buffer_size);
+	    tmp_prop = realloc (*pname_buffer, *pname_buffer_size);
+	    if (!tmp_prop)
+	      return -1;
+	    *pname_buffer = tmp_prop;
+	    property_name = tmp_prop;
+	  } else {
 	    property_name = *pname_buffer;
 	  }
 	  strcpy(property_name, tok);
@@ -832,13 +842,14 @@ char *xml_escape_string (const char *s, xml_escape_quote_t quote_type)
 }
 
 static void xml_parser_dump_node (const xml_node_t *node, int indent) {
+  size_t l;
 
   xml_property_t *p;
   xml_node_t     *n;
 
   printf ("%*s<%s ", indent, "", node->name);
 
-  size_t l = strlen (node->name);
+  l = strlen (node->name);
 
   p = node->props;
   while (p) {
